This is the file-object interface submodule for the birdwell namespace. Offers functions and/or classes
for loading database (redis, postgres) or file (toml, pickle, ini, and json) objects as MutableMappings,
through which changes can be propagated back to their bound source. 
